Name:           virt-who
Version:        0.8
Release:        15%{?dist}
Summary:        Agent for reporting virtual guest IDs to subscription-manager

License:        GPLv2+
URL:            https://fedorahosted.org/virt-who/
Source0:        https://fedorahosted.org/releases/v/i/virt-who/%{name}-%{version}.tar.gz

BuildArch:      noarch
BuildRequires:  python2-devel
Requires:       libvirt-python
Requires:       libvirt
# python-rhsm 1.10.10 has support for sending additional information together with guest uuids
Requires:       python-rhsm >= 1.10.10
# python-suds is required for vSphere support
Requires:       python-suds
# m2crypto is required for Hyper-V support
Requires:       m2crypto
# for journal logging
Requires:       systemd-python
# systemd stuff
BuildRequires:  systemd
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

# Add Hyper-V support
Patch0:         virt-who-0.8-add-hyperv-support.patch
# Create PID file ASAP to prevent service stop fails
Patch1:         virt-who-0.8-create-pid-file-asap.patch
# Help and manpage improvements
Patch2:         virt-who-0.8-help-and-manpage-improvements.patch
# Fix adding https:// to ESX url
Patch3:         virt-who-0.8-fix-adding-https-to-esx-url.patch
# systemd support
Patch4:         virt-who-0.8-systemd.patch
# logging using journal
Patch5:         virt-who-0.8-journal-logging.patch
# Increase ESXi compatibility
Patch6:         virt-who-0.8-exsi-compatibility.patch
# Use instanceUuid when uuid of virtual machine is empty
Patch7:         virt-who-0.8-fix-empty-uuid.patch
# Add satellite support
Patch8:         virt-who-0.8-satellite-support.patch
# Handle more than 100 objects in esx traversal
Patch9:         virt-who-0.8-handle-more-esx-guests.patch
# phere: reconnect before each scan
Patch10:        virt-who-0.8-vsphere-reconnect-before-each-scan.patch
# Check if process defined by PID file exists
Patch11:        virt-who-0.8-check-if-process-defined-by-PID-file-exists.patch 
# Force using background mode when starting from systemd
Patch12:        virt-who-0.8-force-using-background-mode-when-starting-from-syste.patch
# Support sending additional information together with guest uuid on libvirt
Patch13:        virt-who-0.8-support-for-additional-guest-info.patch
# Reconnect to vsphere before each scan to prevent session timeout
Patch14:        virt-who-0.8-always-reconnect-to-vsphere.patch
# Fix python exception when running in vdsm mode
Patch15:        virt-who-0.8-fix-vdsm.patch


%description
Agent that collects information about virtual guests present in the system and
report them to the subscription manager.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1

%build


%install
make DESTDIR=$RPM_BUILD_ROOT install

# Don't run test suite in check section, because it need the system to be
# registered to subscription-manager server


%post
%systemd_post virt-who.service

%preun
%systemd_preun virt-who.service

%postun
%systemd_postun_with_restart virt-who.service 

%files
%doc README README.hyperv LICENSE
%{_bindir}/virt-who
%{_datadir}/virt-who/
%{_unitdir}/virt-who.service
%config(noreplace) %{_sysconfdir}/sysconfig/virt-who
%{_mandir}/man8/virt-who.8.gz


%changelog
* Wed Nov 05 2014 Radek Novacek <rnovacek@redhat.com> 0.8-15
- Fix another error in regular expression in the vdsm patch
- Resolves: rhbz#1158441

* Wed Nov 05 2014 Radek Novacek <rnovacek@redhat.com> 0.8-14
- Fix wrong regular expression in the vdsm patch
- Resolves: rhbz#1158441

* Wed Oct 29 2014 Radek Novacek <rnovacek@redhat.com> 0.8-13
- Fix VDSM mode
- Resolves: rhbz#1158441

* Fri Jan 10 2014 Radek Novacek <rnovacek@redhat.com> 0.8-12
- Support sending additional information together with guest uuid on libvirt
- Reconnect to vsphere before each scan
- Requires python-rhsm >= 1.10.10
- Resolves: rhbz#1048954, rhbz#1047245

* Fri Dec 27 2013 Daniel Mach <dmach@redhat.com> - 0.8-11
- Mass rebuild 2013-12-27

* Wed Dec 11 2013 Radek Novacek <rnovacek@redhat.com> 0.8-10
- Force using background mode when starting from systemd
- Check if process defined by PID file exists
- vsphere: reconnect before each scan
- Resolves: rhbz#1036561, rhbz#1035604, rhbz#1035957

* Thu Nov 21 2013 Radek Novacek <rnovacek@redhat.com> 0.8-9
- Add satellite support
- Handle more than 100 objects in esx traversal
- Use instanceUuid when uuid of virtual machine is empty
- Resolves: rhbz#1032596

* Fri Jun 14 2013 Radek Novacek <rnovacek@redhat.com> 0.8-8
- Increase ESXi compatibility
- Resolves: rhbz#923760

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Nov 27 2012 Radek Novacek <rnovacek@redhat.com> 0.8-6
- Add systemd support
- specfile cleanup

* Thu Oct 25 2012 Radek Novacek <rnovacek@redhat.com> 0.8-5
- Fix adding https:// to ESX url

* Wed Oct 24 2012 Radek Novacek <rnovacek@redhat.com> 0.8-4
- Help and manpage improvements

* Wed Oct 17 2012 Radek Novacek <rnovacek@redhat.com> 0.8-3
- Fix bugs in Hyper-V support (patch rebased)
- Create PID file ASAP to prevent service stop fails

* Thu Oct 11 2012 Radek Novacek <rnovacek@redhat.com> 0.8-2
- Add support for accessing Hyper-V

* Wed Sep 26 2012 Radek Novacek <rnovacek@redhat.com> 0.8-1
- Upstream version 0.8
- RFE: command line improvements
- Add support for accessing RHEV-M
- Fix printing tracebacks on terminal

* Thu Apr 26 2012 Radek Novacek <rnovacek@redhat.com> 0.6-6
- Handle unknown libvirt event properly

* Wed Apr 18 2012 Radek Novacek <rnovacek@redhat.com> 0.6-5
- Enable debug output to be written to stderr
- Log guest list to log even in non-debug mode

* Tue Apr 17 2012 Radek Novacek <rnovacek@redhat.com> 0.6-4
- Fix regression in double fork patch

* Wed Mar 28 2012 Radek Novacek <rnovacek@redhat.com> 0.6-3
- Do double fork when daemon is starting

* Fri Mar 09 2012 Radek Novacek <rnovacek@redhat.com> 0.6-2
- Add python-suds require
- Requires python-rhsm >= 0.98.6

* Thu Mar 01 2012 Radek Novacek <rnovacek@redhat.com> 0.6-1
- Rebase to virt-who-0.6

* Wed Oct 12 2011 Radek Novacek <rnovacek@redhat.com> 0.3-3
- Use updateConsumer API instead of updateConsumerFact (fixes limit 255 chars of uuid list)
- Requires python-rhsm >= 0.96.13 

* Wed Sep 07 2011 Radek Novacek <rnovacek@redhat.com> - 0.3-2
- Add upstream patch that prevents failure when server not implements /status/ command

* Thu Sep 01 2011 Radek Novacek <rnovacek@redhat.com> - 0.3-1
- Add initscript and configuration file

* Mon Aug 22 2011 Radek Novacek <rnovacek@redhat.com> - 0.2-2
- Bump release because of tagging in wrong branch

* Mon Aug 22 2011 Radek Novacek <rnovacek@redhat.com> - 0.2-1
- Update to upstream version 0.2
- Add Requires: libvirt

* Fri Aug 19 2011 Radek Novacek <rnovacek@redhat.com> - 0.1-2
- Add BuildRoot tag (the package will be in RHEL5)

* Wed Aug 10 2011 Radek Novacek <rnovacek@redhat.com> - 0.1-1
- initial import
